/***************************************************************************
 *   Copyright (C) 2008 by C J Plooy                                       *
 *   cornware-cjp@lycos.nl                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef LAGRANGEMFD_H
#define LAGRANGEMFD_H

#include <list>

#include "orbitersdk.h"
#include "kost.h"

class CLagrangeMFD : public MFD
{
public:

	//Interface with Orbiter:
	CLagrangeMFD(DWORD w, DWORD h, VESSEL *vessel);
	~CLagrangeMFD();
	static int MsgProc(UINT msg, UINT mfd, WPARAM wparam, LPARAM lparam);

	void Update(HDC hDC);

	char *ButtonLabel(int bt);
	int ButtonMenu(const MFDBUTTONMENU **menu) const;

	bool ConsumeButton(int bt, int event);
	bool ConsumeKeyBuffered (DWORD key);

	void WriteStatus (FILEHANDLE scn) const;
	void ReadStatus (FILEHANDLE scn);

	void StoreStatus() const;
	void RecallStatus();

	//Button response functions:
	void btnRF1();
	void btnRF2();
	void btnAR();
	void btnTGT();
	void btnNT();
	void btnUPD();
	void btnCLR();

	void autoReference();

	//State of the MFD:
	OBJHANDLE m_Reference1, m_Reference2;
	OBJHANDLE m_Target;

	//Non-stored state:
	double m_ReferenceSimTime;
	double m_ReferencePeriod;
	double m_ReferenceBarycentre; //0.0 is at ref1, 1.0 is at ref2
	kostMatrix3 m_ReferencePlane;
	void updateReferenceOrbit();

protected:
	VESSEL *m_Vessel;
	unsigned int m_Width, m_Height;

	//Temporary results:
	kostVector3 m_Ref1pos, m_Ref2pos, m_Vesselpos, m_Targetpos;
	kostVector3 m_Vesselvel;
	void updatePositions();

	std::list<kostVector3> m_Ref1Trace;
	std::list<kostVector3> m_Ref2Trace;
	std::list<kostVector3> m_VesselTrace;
	std::list<kostVector3> m_TargetTrace;
	double m_LastTraceSimTime;
	void clearTraces();
	void updateTraces();

	kostVector3 m_L[5];
	void updateLagrangePoints();

	double m_Scale;
	void calcScaleAndRange();

	void draw(HDC hDC);

	void drawTracePoint(HDC hDC, std::list<kostVector3> &trace, const kostVector3 &vec) const;
	void drawPoint(HDC hDC, const kostVector3 &vec, unsigned int size=2) const;
	void drawTrace(HDC hDC, const std::list<kostVector3> &trace) const;

	POINT real2screen(const kostVector3 &vec) const;
};


#endif

