/***************************************************************************
 *   Copyright (C) 2008 by C J Plooy                                       *
 *   cornware-cjp@lycos.nl                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <time.h>
#include <windows.h>

#include "orbitersdk.h"


#include "popupmenu.h"

//Global variables to store things for the oapiOpenInputBox fallback
void *InputBox_userPtr = NULL;
menuClbk InputBox_clbk = NULL;

bool InputBoxCallback(void *id,char *str,void *usrdata)
{
	if(InputBox_clbk == NULL) return false; //Should never occur anyway

	return InputBox_clbk(NULL, 0, str, InputBox_userPtr);
}


bool isOrbiter2006p1()
{
	//Check for exact orbiter version

	//First check: what does Orbiter say about itself?
	if(oapiGetOrbiterVersion() != 60929) return false;

	//Second check: test the exact memory contents at some location
	//  (this location is selected carefully: it's not just a random choice)
	unsigned char *testMem = (unsigned char *)0x00431073;

	return 
		testMem[0] == 0xe8 &&
		testMem[1] == 0x58 &&
		testMem[2] == 0x84 &&
		testMem[3] == 0x06 &&
		testMem[4] == 0x00;
}


void oapiCelBodyPopup(void *userPtr, char *title, menuClbk clbk, DWORD flags)
{
	DWORD testProcAddr = 0x00431050;

	//Check for exact orbiter version,
	//and provide alternative if not
	if(!isOrbiter2006p1())
	{
		InputBox_userPtr = userPtr;
		InputBox_clbk    = clbk;
		oapiOpenInputBox(title, InputBoxCallback, "", 20, NULL);
		return;
	}

	/*
	In the actual function 0x00431050, ecx (the this pointer)
	points to an InstrUser object. However, it is not
	dereferenced, so we can put any user-defined pointer
	in it.
	*/
	__asm mov ecx, [userPtr]
	__asm push [flags]
	__asm push [clbk]
	__asm push [title]
	__asm call testProcAddr
}

void oapiTargetPopup(void *userPtr, char *title, menuClbk clbk, OBJHANDLE refObj, DWORD flags)
{
	DWORD testProcAddr = 0x00431190;

	//Check for exact orbiter version,
	//and provide alternative if not
	if(!isOrbiter2006p1())
	{
		InputBox_userPtr = userPtr;
		InputBox_clbk    = clbk;
		oapiOpenInputBox(title, InputBoxCallback, "", 20, NULL);
		return;
	}

	/*
	In the actual function 0x00431190, ecx (the this pointer)
	points to an InstrUser object. However, it is not
	dereferenced, so we can put any user-defined pointer
	in it.
	*/
	__asm mov ecx, [userPtr]
	__asm push [flags]
	__asm push [refObj]
	__asm push [clbk]
	__asm push [title]
	__asm call testProcAddr
}

